# Generated by ariadne-codegen
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import CreditsBalanceSummaryFragment


class GetCreditBalance(BaseModel):
    credit_balance_summary: "GetCreditBalanceCreditBalanceSummary" = Field(
        alias="creditBalanceSummary"
    )


class GetCreditBalanceCreditBalanceSummary(CreditsBalanceSummaryFragment):
    pass


GetCreditBalance.model_rebuild()



# Generated by ariadne-codegen
# Source: operations.graphql

from typing import List, Literal, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntitlementsStateAccessDeniedReason
from .fragments import EntitlementFragment


class GetEntitlementsState(BaseModel):
    entitlements_state: "GetEntitlementsStateEntitlementsState" = Field(
        alias="entitlementsState"
    )


class GetEntitlementsStateEntitlementsState(BaseModel):
    typename__: Literal["EntitlementsState"] = Field(alias="__typename")
    entitlements: List["GetEntitlementsStateEntitlementsStateEntitlements"]
    access_denied_reason: Optional[EntitlementsStateAccessDeniedReason] = Field(
        alias="accessDeniedReason"
    )


class GetEntitlementsStateEntitlementsStateEntitlements(EntitlementFragment):
    pass


GetEntitlementsState.model_rebuild()
GetEntitlementsStateEntitlementsState.model_rebuild()
